@@ -8,10 +8,10 @@ from pathlib import Path
 from shlex import quote
 from typing import Any, Dict, Iterator, List, Optional, Union
 
-from loguru import logger
 from stdlib_list import stdlib_list
 from tomlkit import dumps, parse
 
+from .console import console, style_str
 from .datatypes import Dependency, Pyproject, RepoConfig
 from .errors import DirectoryNotFoundError, PackageNotFoundError, PyprojectNotFoundError
 from .utils import current_directory, run
@@ -44,7 +44,7 @@ class Project:
         self.pyproject_content = self.pyproject_file.read_text()
         # If file content is not valid, a ValidationError is
         self._pyproject = parse(self.pyproject_content)
-        self.pyproject = Pyproject(**self._pyproject["tool"]["poetry"])
+        self.pyproject = Pyproject(**self._pyproject["tool"]["poetry"])  # type: ignore
 
     def __repr__(self) -> str:
         return f"Project(name={self.pyproject.name}, root={self.root})"
@@ -144,15 +144,27 @@ class Project:
         if self.pyproject.name in skip:
             return
         with current_directory(self.root):
-            logger.debug(f"Installing project {self.pyproject.name}")
+            console.print(
+                f"Installing project {style_str(self.pyproject.name, 'bold blue')}"
+            )
             extras_opts = " ".join(["-E " + quote(extra) for extra in extras])
-            run(f"poetry install {extras_opts}")
+            try:
+                run(f"poetry install {extras_opts}")
+            except Exception:
+                console.print(
+                    f"Failed to install {self.pyproject.name} from {style_str(self.root, 'red')}",
+                    style="red",
+                )
+            console.print(
+                f"Successfully installed {self.pyproject.name} from {style_str(self.root, 'green')}",
+                style="green",
+            )
 
     def build(self, format: Optional[str] = None) -> None:
         """Build package using `poetry build`."""
         with current_directory(self.root):
             format_opt = f"--format {quote(format)}" if format else ""
-            logger.debug(f"Building package {self.pyproject.name}")
+            console.print(f"Building package {style_str(self.pyproject.name, 'blue')}")
             run(f"poetry build {format_opt}")
 
     def test(
@@ -164,48 +176,66 @@ class Project:
         cov_opts = " ".join((f"--cov {quote(src)}" for src in set(self.src + add_src)))
         with current_directory(self.root):
             cmd = f"pytest {cov_opts} {expr_opts} {marker_opts}"
-            logger.debug(f"Testing package {self.pyproject.name} with command: {cmd}")
+            console.print(
+                f"[bold blue]Testing[/bold blue] package {style_str(self.pyproject.name, 'blue')} with command: {style_str(cmd, 'blue')}"
+            )
             run(cmd)
 
     def lint(self) -> None:
         """Lint package and tests using `flake8`."""
+        cmd = f"flake8 {' '.join([quote(src) for src in self.src])}" + (
+            " tests/" if self.tests_found else ""
+        )
         with current_directory(self.root):
-            logger.debug(f"Linting package {self.pyproject.name}")
-            cmd = f"flake8 {' '.join([quote(src) for src in self.src])}" + (
-                " tests/" if self.tests_found else ""
+            console.print(
+                f"[bold blue]Linting[/bold blue] package {style_str(self.pyproject.name, 'blue')} with command: {style_str(cmd, 'blue')}"
             )
             run(cmd)
 
     def format(self) -> None:
         """Format package and tests using `isort` and `black`."""
+        src_dirs = " ".join([quote(src) for src in self.src])
+        test_dirs = " tests/" if self.tests_found else ""
+        black_cmd = f"black {src_dirs}" + test_dirs
+        isort_cmd = f"isort {src_dirs}" + test_dirs
         with current_directory(self.root):
-            logger.debug(f"Formatting package {self.pyproject.name}")
-            run(
-                f"black {' '.join([quote(src) for src in self.src])}"
-                + (" tests/" if self.tests_found else "")
+            console.print(
+                f"[bold blue]Formatting[/bold blue] package {style_str(self.pyproject.name, 'blue')} with command: {style_str(black_cmd, 'blue')}"
             )
-            run(
-                f"isort {' '.join([quote(src) for src in self.src])}"
-                + (" tests/" if self.tests_found else "")
+            run(black_cmd)
+            console.print(
+                f"[bold blue]Sorting[/bold blue] imports for package {style_str(self.pyproject.name, 'blue')} with command: {style_str(isort_cmd, 'blue')}"
             )
+            run(isort_cmd)
+
+    def typecheck(self) -> None:
+        """Run `mypy` against package source."""
+        sources = " ".join([quote(src) for src in self.src])
+        cmd = f"mypy {sources}"
+        console.print(
+            f"[bold blue]Typechecking[/bold blue] package {style_str(self.pyproject.name, 'blue')} with command: {style_str(cmd, 'blue')}"
+        )
+        run(cmd)
 
     def bump(self, version: str) -> None:
         """Bump package version using `poetry version`."""
-        logger.debug(
-            f"Bumping package {self.pyproject.name} from version {version} to {version}"
+        console.print(
+            f"[bold blue]Bumping[/bold blue] package {style_str(self.pyproject.name, 'blue')} from version {style_str(self.pyproject.version, 'bold blue')} to {style_str(version, 'bold blue')}"
         )
         with current_directory(self.root):
             deps_to_bump = {
                 dep.pyproject.name: f"^{version}" for dep in self.private_dependencies
             }
             if deps_to_bump:
-                logger.debug(f"Bumping relative dependencies: {deps_to_bump}")
+                console.print(
+                    f"[blue]Bumping relative dependencies[/blue]: {list(deps_to_bump)}"
+                )
                 self.update_dependencies(deps_to_bump)
-            old_version = self.pyproject.version
             self.set_version(version)
             run("poetry lock --no-update")
-            logger.info(
-                f"Successfully bumped package {self.pyproject.name} from version {old_version} to {version}"
+            console.print(
+                f"Successfully bumped package {self.pyproject.name}",
+                style="green",
             )
 
     def clean(self, no_dist: bool = False) -> None:
@@ -227,15 +257,9 @@ class Project:
     def update(self) -> None:
         """Update package dependencies using `poetry udpate`."""
         with current_directory(self.root):
-            logger.debug(f"Updating package {self.pyproject.name}")
+            console.print(f"Updating package {self.pyproject.name}")
             run("poetry update")
 
-    def typecheck(self) -> None:
-        """Run `mypy` against package source."""
-        logger.debug(f"Typechecking package {self.pyproject.name}")
-        sources = " ".join([quote(src) for src in self.src])
-        run(f"mypy {sources}")
-
     def export_requirements(
         self, requirements: Union[str, Path] = "requirements.txt", mode: str = ">"
     ) -> None:
@@ -248,7 +272,7 @@ class Project:
 
     def export(self, clean: bool = True) -> None:
         """Export packages and its dependencies to directory."""
-        logger.debug(f"Exporting package {self.pyproject.name} and its dependencies")
+        console.print(f"Exporting package {self.pyproject.name} and its dependencies")
         if clean:
             self.clean()
         export = self.root / "export"
@@ -288,25 +312,34 @@ class Project:
         )
         shutil.rmtree(export)
 
+    def add_dep(self, name: str, *, dev: bool = False) -> None:
+        with current_directory(self.root):
+            dev_opt = "--dev" if dev else ""
+            cmd = f"poetry add {name} {dev_opt}".strip()
+            console.print(
+                f"[blue]Installing[/blue] dependency [bold blue]{name}[/bold blue] for project [bold blue]{self.pyproject.name}[/bold blue] with command [blue]{quote(cmd)}[/blue]"
+            )
+            run(cmd)
+
     def set_version(self, value: str) -> None:
-        self._pyproject["tool"]["poetry"]["version"] = value
-        self.pyproject = Pyproject.construct(**self._pyproject["tool"]["poetry"])
+        self._pyproject["tool"]["poetry"]["version"] = value  # type: ignore
+        self.pyproject = Pyproject.construct(**self._pyproject["tool"]["poetry"])  # type: ignore
         self.pyproject_content = dumps(self._pyproject)
         self.pyproject_file.write_text(self.pyproject_content)
 
     def set_authors(self, values: List[str]) -> None:
-        self._pyproject["tool"]["poetry"]["authors"] = [
+        self._pyproject["tool"]["poetry"]["authors"] = [  # type: ignore
             value.lower() for value in values
         ]
-        self.pyproject = Pyproject.construct(**self._pyproject["tool"]["poetry"])
+        self.pyproject = Pyproject.construct(**self._pyproject["tool"]["poetry"])  # type: ignore
         self.pyproject_content = dumps(self._pyproject)
         self.pyproject_file.write_text(self.pyproject_content)
 
     def set_include_packages(self, values: List[str]) -> None:
-        self._pyproject["tool"]["poetry"]["packages"] = [
+        self._pyproject["tool"]["poetry"]["packages"] = [  # type: ignore
             {"include": value} for value in values
         ]
-        self.pyproject = Pyproject.construct(**self._pyproject["tool"]["poetry"])
+        self.pyproject = Pyproject.construct(**self._pyproject["tool"]["poetry"])  # type: ignore
         self.pyproject_content = dumps(self._pyproject)
         self.pyproject_file.write_text(self.pyproject_content)
 
@@ -318,8 +351,7 @@ class Project:
         for key, value in new_deps.items():
             if isinstance(value, Dependency):
                 new_deps[key] = value.dict(exclude_unset=True)
-        logger.debug(f"New dependencies: {new_deps}")
-        self._pyproject["tool"]["poetry"]["dependencies"] = new_deps
+        self._pyproject["tool"]["poetry"]["dependencies"] = new_deps  # type: ignore
         self.pyproject_content = dumps(self._pyproject)
         self.pyproject_file.write_text(self.pyproject_content)
 
@@ -364,6 +396,8 @@ class Monorepo(Project):
         """Get a subset of packages from name."""
         if not packages:
             return self._projects
+        if not isinstance(packages, list):
+            packages = list(packages)
         unknown = [name for name in packages if name not in self.project_names]
         if len(unknown) > 1:
             raise PackageNotFoundError(f"Cannot find packages: {', '.join(unknown)}")
@@ -372,8 +406,20 @@ class Monorepo(Project):
         return [self.projects[package] for package in packages]
 
     def install_packages(
-        self, packages: List[str] = [], extras: List[str] = [], skip: List[str] = []
+        self,
+        packages: Optional[List[str]] = None,
+        extras: Optional[List[str]] = None,
+        skip: Optional[List[str]] = None,
     ) -> None:
+        if packages is None:
+            packages = []
+        packages = list(packages)
+        if extras is None:
+            extras = []
+        extras = list(extras)
+        if skip is None:
+            skip = []
+        skip = list(skip)
         projects = self.get_packages(packages)
         for project in projects:
             for dep in project.private_dependencies:
@@ -451,10 +497,17 @@ class Monorepo(Project):
                 continue
             project.format()
 
-    def update_packages(self, packages: List[str] = []) -> None:
+    def update_packages(self, packages: Optional[List[str]] = None) -> None:
+        packages = packages or []
         for project in self.get_packages(packages):
             project.update()
 
+    def add_dependency(
+        self, name: str, packages: List[str] = [], dev: bool = False
+    ) -> None:
+        for package in self.get_packages(packages):
+            package.add_dep(name, dev=dev)
+
     def new_library(self, name: str) -> None:
         self._new_project(name, "libraries")
 
@@ -462,45 +515,50 @@ class Monorepo(Project):
         self._new_project(name, "plugins")
 
     def new_app(self, name: str) -> None:
-        self._new_project(name, "applications")
+        self._new_project(name, "applications", sources_parent="apps")
 
-    def _new_project(self, name: str, folder: str) -> None:
-        # Simply replace name for the moment
-        name = name.replace("-", "_").replace(" ", "_")
-        # Create project directory
+    def _new_project(
+        self, name: str, folder: str, sources_parent: Optional[str] = None
+    ) -> None:
+        # Declare variable type
+        to_include: Optional[str]
+        # Create project directory. Dash character is allowed in project directory name
         project_root = self.root / folder / name
         project_root.mkdir(parents=True, exist_ok=True)
-        # Create pyproject.toml
-        with current_directory(project_root):
-            run(f"poetry init -n --name {quote(name)}")
+        # Convert dash to underscores for python package names
+        package_name = name.replace("-", "_")
+        # Relevant only when using a prefix in project configuration
+        if self.config.prefix:
+            sources_root = project_root / self.config.prefix.replace("-", "_")
+            to_include = self.config.prefix.replace("-", "_")
+            if package_name.startswith(self.config.prefix + "_"):
+                package_name = package_name[len(self.config.prefix) + 1 :]
+        else:
+            to_include = None
+        if sources_parent:
+            sources_dir = sources_root / sources_parent / package_name
+        else:
+            sources_dir = sources_root / package_name
+        # Bootstrap source directory
+        sources_dir.mkdir(parents=True, exist_ok=False)
+        init_file = sources_dir / "__init__.py"
+        init_file.touch()
         # Bootstrap test directory
         project_tests = project_root / "tests"
         project_tests.mkdir(exist_ok=False, parents=False)
         conftest = project_tests / "conftest.py"
         conftest.touch()
+        # Create pyproject.toml
+        with current_directory(project_root):
+            run(f"poetry init -n --name {name}")
         # Bootstrap source directory
-        if self.config.prefix:
-            sources_dir = (
-                project_root
-                / self.config.prefix.replace("-", "_")
-                / name.replace(f"{self.config.prefix}-", "").replace("-", "_")
+        if package_name in stdlib_list():
+            console.print(
+                f"Warning: Generated module with name {package_name}. "
+                f"The {package_name} module already exists in the standard library. "
+                "You're gonna have a bad time.",
+                style="yellow",
             )
-        else:
-            sources_dir = project_root / name.replace("-", "_")
-        if sources_dir.name in stdlib_list():
-            logger.warning(
-                f"Generated module with name {sources_dir}. "
-                f"The {sources_dir} module already exists in the standard library."
-            )
-        # Declare variable type
-        to_include: Optional[str]
-        if self.config.prefix:
-            to_include = self.config.prefix.replace("-", "_")
-        else:
-            to_include = None
-        sources_dir.mkdir(parents=True, exist_ok=False)
-        init_file = sources_dir / "__init__.py"
-        init_file.touch()
         # Create project instance
         project = Project(project_root)
         # Update project version
